@@ -7,10 +7,10 @@ class FirewallSync(Task):
     """
     Updates the firewall on a live server.
 
-    Calls 'firewall.update_files' and then updates the
+    Calls ``firewall.update_files`` and then updates the
     remote servers using 'firewall.sync_single'
 
-    Takes the same arguments as 'firewall.update_files
+    Takes the same arguments as ``firewall.update_files``
 
     While this task will deploy any changes it makes they
     are not commited to your repo. You should review any
@@ -21,6 +21,8 @@ class FirewallSync(Task):
     serial = True
 
     def run(self, section=None):
+        """
+        """
         execute('firewall.update_files', section=section)
         if section:
             sections = [section]
